import os

from blue_options.env import load_config, load_env
from blue_objects.env import ABCLI_AWS_S3_BUCKET_NAME, ABCLI_AWS_S3_PREFIX

load_env(__name__)
load_config(__name__)


abcli_is_github_workflow = os.getenv("GITHUB_ACTIONS", "")

abcli_aws_ec2_default_image_name = os.getenv("abcli_aws_ec2_default_image_name", "")
abcli_aws_ec2_default_instance_type = os.getenv(
    "abcli_aws_ec2_default_instance_type", ""
)
abcli_aws_ec2_default_template = os.getenv("abcli_aws_ec2_default_template", "")
abcli_aws_ec2_image_id_abcli = os.getenv("abcli_aws_ec2_image_id_abcli", "")
abcli_aws_ec2_image_id_abcli_g4dn = os.getenv("abcli_aws_ec2_image_id_abcli_g4dn", "")
abcli_aws_ec2_image_id_bolt = os.getenv("abcli_aws_ec2_image_id_bolt", "")
abcli_aws_ec2_key_name = os.getenv("abcli_aws_ec2_key_name", "")
abcli_aws_ec2_security_group_ids = os.getenv("abcli_aws_ec2_security_group_ids", "")
abcli_aws_ec2_subnet_id = os.getenv("abcli_aws_ec2_subnet_id", "")
abcli_aws_ec2_templates_bolt = os.getenv("abcli_aws_ec2_templates_bolt", "")
abcli_aws_ec2_templates_bolt_gpu = os.getenv("abcli_aws_ec2_templates_bolt_gpu", "")

abcli_blue_sbc_application = os.getenv("abcli_blue_sbc_application", "")

abcli_display_fullscreen = os.getenv("abcli_display_fullscreen", "")

abcli_git_ssh_key_name = os.getenv("abcli_git_ssh_key_name", "")

abcli_gpu = os.getenv("abcli_gpu", "")

ABCLI_MESSENGER_RECIPIENTS = os.getenv("ABCLI_MESSENGER_RECIPIENTS", "")

abcli_path_abcli = os.getenv("abcli_path_abcli", "")

ABCLI_PATH_IGNORE = os.getenv("ABCLI_PATH_IGNORE", "")

abcli_papertrail_dest_host = os.getenv("abcli_papertrail_dest_host", "")
abcli_papertrail_dest_port = os.getenv("abcli_papertrail_dest_port", "")

abcli_youtube_api_key = os.getenv("abcli_youtube_api_key", "")

STABILITY_KEY = os.getenv("STABILITY_KEY", "")

VANWATCH_TEST_OBJECT = os.getenv("VANWATCH_TEST_OBJECT", "vanwatch-test-object-v2")

NGROK_AUTHTOKEN = os.getenv("NGROK_AUTHTOKEN", "")

COMFYUI_PASSWORD = os.getenv("COMFYUI_PASSWORD", "")

ABCLI_MLFLOW_STAGES = os.getenv("ABCLI_MLFLOW_STAGES", "")

ABCLI_AWS_BATCH_JOB_STATUS_LIST = os.getenv("ABCLI_AWS_BATCH_JOB_STATUS_LIST", "")



import time
import pytest
from abcli.plugins.ssm.functions import get_secret, put_secret, rm_secret
from blue_options.string import random


def test_ssm():
    secret_name = "pytest-{}".format(random())
    secret_value = random()

    success, _ = put_secret(secret_name, secret_value)
    assert success

    time.sleep(1)

    success, secret_value_received = get_secret(secret_name)
    assert success, secret_value_received
    assert not secret_value_received or (
        secret_value_received == secret_value
    ), f"{secret_value_received} != {secret_value}"

    success = rm_secret(secret_name)
    assert success



from abcli import NAME
from blue_objects.env import abcli_object_name
from abcli.logger import logger


NAME = f"{NAME}.plugins.seed"


def log(
    object_name: str = ".",
    target: str = "open_object",
):
    object_name = abcli_object_name if object_name == "." else object_name

    lines = []
    if target == "download_object":
        lines = [
            f"abcli select {object_name}",
            "abcli download",
            "open .",
        ]
    elif target == "open_object":
        lines = [
            f"abcli select {object_name}",
            "open .",
        ]

    if not lines:
        logger.error(f"-{NAME}: seed: log({target}): target not found.")
    else:
        logger.info("; ".join(lines))



from typing import List

from blue_options.terminal import show_usage


def help_(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@env",
            "backup",
        ],
        "backup env -> $abcli_path_env_backup.",
        mono=mono,
    )


def help_list(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@env",
            "backup",
            "list",
        ],
        "list $abcli_path_env_backup.",
        mono=mono,
    )


help_functions = {
    "": help_,
    "list": help_list,
}



from blue_objects.env import abcli_object_name
from abcli.logger import logger

logger.info(f"{abcli_object_name}: started.")

# --- your script here

logger.info("Hello World!")

# /script

logger.info(f"{abcli_object_name}: completed.")



from typing import List

from blue_options.terminal import show_usage, xtra


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "dashboard"

    return show_usage(
        [
            "@sagemaker",
            "browse",
            f"[{options}]",
        ],
        "browse sagemaker.",
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
}



import os
from typing import List

from blue_options.terminal import show_usage, xtra

from abcli.help.pypi import build_options as pypi_build_options


def help(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "<repo_name>",
            "<command-line>",
        ],
        "run '@git <command-line>' in <repo_name>.",
        mono=mono,
    )


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "actions"

    return show_usage(
        [
            "@git",
            "browse",
            "[ . | - | <repo-name> ]",
            f"[{options}]",
        ],
        "browse <repo-name>.",
        mono=mono,
    )


def help_checkout(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("~fetch,~pull,", mono=mono),
            "rebuild",
        ]
    )

    return show_usage(
        [
            "@git",
            "checkout",
            "<branch-name>",
            f"[{options}]",
        ],
        "git checkout <branch-name>.",
        mono=mono,
    )


def help_clone(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("cd,~from_template,if_cloned,init,", mono=mono),
            "install",
            xtra(",object,pull,source=<username/repo_name>", mono=mono),
        ]
    )

    return show_usage(
        [
            "@git",
            "clone",
            "<repo-name>",
            f"[{options}]",
        ],
        "clone <repo-name>.",
        mono=mono,
    )


def help_create_branch(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("~increment_version,~push,~timestamp", mono=mono)

    return show_usage(
        [
            "@git",
            "create_branch",
            "<branch-name>",
            f"[{options}]",
        ],
        "create <branch-name> in the repo.",
        mono=mono,
    )


def help_create_pull_request(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "create_pull_request",
        ],
        "create a pull request in the repo.",
        mono=mono,
    )


def help_get_branch(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "get_branch",
        ],
        "get git branch name.",
        mono=mono,
    )


def help_get_repo_name(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "get_repo_name",
        ],
        "get repo name.",
        mono=mono,
    )


def help_increment_version(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "diff"

    args = [
        "[--verbose 1]",
    ]

    return show_usage(
        [
            "@git",
            "++ | increment | increment_version",
            f"[{options}]",
        ]
        + args,
        "increment repo version.",
        mono=mono,
    )


def help_pull(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("~all,", mono=mono),
            "init",
        ]
    )

    return show_usage(
        [
            "@git",
            "pull",
            f"[{options}]",
        ],
        "pull.",
        mono=mono,
    )


def help_push(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("~action,", mono=mono),
            "browse",
            xtra(",~create_pull_request,", mono=mono),
            "first",
            xtra(",~increment_version,~status,", mono=mono),
            "~workflow",
        ]
    )

    build_options = f"build,{pypi_build_options}"

    return show_usage(
        [
            "@git",
            "push",
            "<message>",
            f"[{options}]",
            f"[{build_options}]",
        ],
        "push to the repo.",
        mono=mono,
    )


def help_recreate_ssh(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "recreate_ssh",
        ],
        "recreate github ssh key.",
        mono=mono,
    )


def help_reset(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "reset",
        ],
        "reset to the latest commit of the current branch.",
        mono=mono,
    )


def help_review(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "review",
        ],
        "review the repo.",
        mono=mono,
    )


def help_status(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "~all"

    return show_usage(
        [
            "@git",
            "status",
            f"[{options}]",
        ],
        "show git status.",
        mono=mono,
    )


def help_sync_fork(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@git",
            "sync_fork",
            "<branch-name>",
        ],
        "sync fork w/ upstream.",
        mono=mono,
    )


help_functions = {
    "": help,
    "browse": help_browse,
    "checkout": help_checkout,
    "clone": help_clone,
    "create_branch": help_create_branch,
    "create_pull_request": help_create_pull_request,
    "get_branch": help_get_branch,
    "get_repo_name": help_get_repo_name,
    "increment_version": help_increment_version,
    "pull": help_pull,
    "push": help_push,
    "recreate_ssh": help_recreate_ssh,
    "reset": help_reset,
    "review": help_review,
    "status": help_status,
    "sync_fork": help_sync_fork,
}



from typing import List

from blue_options.terminal import show_usage

from abcli.help.eval import options as eval_options


def help_repeat(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            "count=<count>,",
            eval_options(mono=mono),
        ]
    )

    return show_usage(
        [
            "@repeat",
            f"[{options}]",
            "<command-line>",
        ],
        "repeat <command-line>.",
        mono=mono,
    )
